import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class ConsumerPage extends StatelessWidget {
  const ConsumerPage({super.key});

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (_) => Counter(),
      child: Scaffold(
        appBar: AppBar(
          title: const Text('Consumer Example'),
        ),
        body: const Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              CounterConsumer(),
              CounterConsumer2(),
              CounterConsumer3(),
            ],
          ),
        ),
      ),
    );
  }
}

class Counter extends ChangeNotifier {
  int _count = 0;
  int get count => _count;

  void increment() {
    _count++;
    notifyListeners();
  }
}

class CounterConsumer extends StatelessWidget {
  const CounterConsumer({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer<Counter>(
      builder: (context, counter, child) {
        return Column(
          children: [
            Text('Count: ${counter.count}'),
            ElevatedButton(
              onPressed: counter.increment,
              child: const Text('Increment'),
            ),
          ],
        );
      },
    );
  }
}

class CounterConsumer2 extends StatelessWidget {
  const CounterConsumer2({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer2<Counter, Counter>(
      builder: (context, counter1, counter2, child) {
        return Text('Same counter: ${counter1.count} = ${counter2.count}');
      },
    );
  }
}

class CounterConsumer3 extends StatelessWidget {
  const CounterConsumer3({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer<Counter>(
      builder: (context, counter, child) {
        return Column(
          children: [
            child!,
            Text('Count: ${counter.count}'),
          ],
        );
      },
      child: const Text('This widget will not rebuild'),
    );
  }
}
